﻿//*****************************************************************************
// Description     : Definition of IO functions
// Target Device   : APN504X
// Target Platform : Windows, .NET Framework, C#
// Date            : Auguts 2017
// Version         : 1.0
//*****************************************************************************
using System;
using System.IO;

namespace APN504X_sample
{
	public static class Files
	{
		//#########################################################################
		//  Name      : file_write_header
		//  Function  : write header to the text file
		//  Arguments :
		//      in pName    : file name
		//      in now_time : actual measurement time(msec)
		//      in in_cps   : array of input count rate(cps)
		//      in th_cps   : array of throughput count rate(cps)
		//  Return :
		//       0 : success
		//      -1 : failed to open file
		//#########################################################################
		public static int file_write_header(string pName, uint now_time, uint[] in_cps, uint[] th_cps)
		{
			try {
				// open file(create)
				StreamWriter writer = File.CreateText(pName);

				// write header information
				writer.WriteLine("[header]");
				writer.WriteLine("Real time(s), {0}", now_time/1000);
				writer.WriteLine("Input rate(cps), {0},{1},{2},{3}", in_cps[0], in_cps[1], in_cps[2], in_cps[3]);
				writer.WriteLine("Throughput rate(cps), {0},{1},{2},{3}", th_cps[0], th_cps[1], th_cps[2], th_cps[3]);

				// close file
				writer.Close();
			}
			catch (Exception) {
				// failed to open file
				return(-1);
			}

			return(0);
		}


		//#########################################################################
		//  Name      : file_write_data
		//  Function  : write data to the text file
		//  Arguments :
		//      in pName : file name
		//      in chnum : number of CHs
		//      in pBuff : array of data
		//  Return :
		//       0 : success
		//      -1 : failed to open file
		//#########################################################################
		public static int file_write_data(string pName, int chnum, byte[][] pBuff)
		{
			int i, j;

			try {
				// open file(append)
				StreamWriter writer = File.AppendText(pName);

				writer.WriteLine("[data]");

				// write data in unit of unsigned int
				for (i = 0; i < Defines.NUM_DATA; i++) {
					writer.Write( BitConverter.ToUInt32(pBuff[0], i*4) );			// CH1
					for (j = 1; j < chnum; j++) {									// CH2-
						writer.Write(",{0}", BitConverter.ToUInt32(pBuff[j], i*4) );
					}
					writer.WriteLine();
				}

				// close file
				writer.Close();
			}
			catch (Exception) {
				// failed to open file
				return(-1);
			}

			return(i);
		}

	} // end of class
} // end of namespace

